Crate metriken_exposition

Crate metriken_exposition 

Exposition of Metriken metrics

Provides a standardized struct for a snapshot of the metric readings as well as a way of producing the snapshots.

Structs

Counter
Gauge
Histogram
MsgpackToParquet
A struct for converting msgpack’d metriken snapshots into a parquet file.
ParquetCompression
ParquetOptions
Options for ParquetWriter controlling the output parquet file.
ParquetSchema
Converts metrics snapshot data into parquet
ParquetWriter
PrometheusOptions
Options for Prometheus text format rendering.
SnapshotV1
Contains a snapshot of metric readings.
SnapshotV2
Contains a snapshot of metric readings.
Snapshotter
Produces a snapshot of metric readings.
SnapshotterBuilder
Used to build a new Snapshotter.

Enums

ParquetHistogramType
Type representation for histograms within the parquet file.
Snapshot

Functions

prometheus_text
Render all registered metriken metrics in Prometheus text exposition format.